# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/pkg/apis/catalog/v1alpha1/generated.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from k8s.io.api.core.v1 import generated_pb2 as k8s_dot_io_dot_api_dot_core_dot_v1_dot_generated__pb2
from k8s.io.apimachinery.pkg.api.resource import generated_pb2 as k8s_dot_io_dot_apimachinery_dot_pkg_dot_api_dot_resource_dot_generated__pb2
from k8s.io.apimachinery.pkg.apis.meta.v1 import generated_pb2 as k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2
from k8s.io.apimachinery.pkg.runtime import generated_pb2 as k8s_dot_io_dot_apimachinery_dot_pkg_dot_runtime_dot_generated__pb2
from k8s.io.apimachinery.pkg.runtime.schema import generated_pb2 as k8s_dot_io_dot_apimachinery_dot_pkg_dot_runtime_dot_schema_dot_generated__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nGgithub.com/metaprov/modelaapi/pkg/apis/catalog/v1alpha1/generated.proto\x12\x37github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1\x1a\"k8s.io/api/core/v1/generated.proto\x1a\x34k8s.io/apimachinery/pkg/api/resource/generated.proto\x1a\x34k8s.io/apimachinery/pkg/apis/meta/v1/generated.proto\x1a/k8s.io/apimachinery/pkg/runtime/generated.proto\x1a\x36k8s.io/apimachinery/pkg/runtime/schema/generated.proto\"\xae\x01\n\nAccessSpec\x12\x0c\n\x04port\x18\x01 \x01(\x05\x12\x10\n\x08nodePort\x18\x02 \x01(\x05\x12\x0c\n\x04path\x18\x03 \x01(\t\x12\x12\n\naccessType\x18\x04 \x01(\t\x12\x0c\n\x04rest\x18\x05 \x01(\x08\x12\x12\n\nauthMethod\x18\x06 \x01(\t\x12<\n\x0f\x61pikeySecretRef\x18\x07 \x01(\x0b\x32#.k8s.io.api.core.v1.SecretReference\"\xa5\x01\n\tAlgorithm\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12T\n\x04spec\x18\x02 \x01(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.AlgorithmSpec\"\xa4\x01\n\rAlgorithmList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12Q\n\x05items\x18\x02 \x03(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.Algorithm\"\xc0\x01\n\rAlgorithmSpec\x12\x15\n\rframeworkName\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0b\n\x03url\x18\x03 \x01(\t\x12\r\n\x05tasks\x18\x04 \x03(\t\x12\x0e\n\x06sparse\x18\x05 \x01(\x08\x12W\n\x06ranges\x18\x06 \x03(\x0b\x32G.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.ParameterRange\"\xf3\x01\n\x05\x43loud\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12P\n\x04spec\x18\x02 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.CloudSpec\x12T\n\x06status\x18\x03 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.CloudStatus\"\x9c\x01\n\tCloudList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12M\n\x05items\x18\x02 \x03(\x0b\x32>.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.Cloud\"\xec\x02\n\tCloudSpec\x12\x19\n\x11\x64\x65\x66\x61ultRegionName\x18\x01 \x01(\t\x12\x1f\n\x17\x64\x65\x66\x61ultMachineClassName\x18\x02 \x01(\t\x12\x1b\n\x13\x64\x65\x66\x61ultGpuClassName\x18\x03 \x01(\t\x12]\n\x0emachineClasses\x18\x04 \x03(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.MachineClass\x12U\n\ngpuClasses\x18\x05 \x03(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.GpuClass\x12P\n\x07regions\x18\x06 \x03(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.Region\"\xc7\x01\n\x0b\x43loudStatus\x12_\n\x0cmachineCosts\x18\x01 \x03(\x0b\x32I.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.MachineClassCost\x12W\n\x08gpuCosts\x18\x02 \x03(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.GpuClassCost\"A\n\x0c\x43ompilerSpec\x12\x0e\n\x06\x65nable\x18\x01 \x01(\x08\x12\x10\n\x08\x63ompiler\x18\x02 \x01(\t\x12\x0f\n\x07targets\x18\x03 \x03(\t\"l\n\x0f\x43onfusionMatrix\x12Y\n\x04rows\x18\x01 \x03(\x0b\x32K.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.ConfusionMatrixRow\"F\n\x12\x43onfusionMatrixRow\x12\t\n\x01t\x18\x01 \x01(\t\x12\t\n\x01p\x18\x02 \x01(\t\x12\r\n\x05\x63ount\x18\x03 \x01(\x05\x12\x0b\n\x03pct\x18\x04 \x01(\x01\";\n\x0c\x43ontainerLog\x12\x0b\n\x03job\x18\x01 \x01(\t\x12\x11\n\tcontainer\x18\x02 \x01(\t\x12\x0b\n\x03key\x18\x03 \x01(\t\"\"\n\nCurvePoint\x12\t\n\x01x\x18\x01 \x01(\x01\x12\t\n\x01y\x18\x02 \x01(\x01\"(\n\nDataCenter\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\"\xc5\x04\n\x0c\x44\x61taTestCase\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x12\n\nassertThat\x18\x03 \x01(\t\x12\x36\n\tentityRef\x18\x04 \x01(\x0b\x32#.k8s.io.api.core.v1.ObjectReference\x12\x39\n\x0c\x63ompareToRef\x18\x05 \x01(\x0b\x32#.k8s.io.api.core.v1.ObjectReference\x12\x0e\n\x06\x63olumn\x18\x06 \x01(\t\x12\x0c\n\x04type\x18\x07 \x01(\t\x12\x0e\n\x06metric\x18\x08 \x01(\t\x12\x15\n\rexpectedValue\x18\t \x01(\x01\x12\x18\n\x10\x65xpectedCategory\x18\n \x01(\t\x12\r\n\x05lower\x18\x0b \x01(\x01\x12\r\n\x05upper\x18\x0c \x01(\x01\x12\x13\n\x0b\x65xpectedSet\x18\r \x03(\t\x12\x16\n\x0elowerInclusive\x18\x0e \x01(\x08\x12\x16\n\x0eupperInclusive\x18\x0f \x01(\x08\x12\x11\n\tgenerated\x18\x10 \x01(\x08\x12\x0c\n\x04tags\x18\x11 \x03(\t\x12\x0f\n\x07\x63olumn2\x18\x12 \x01(\t\x12\x37\n\nentityRef2\x18\x13 \x01(\x0b\x32#.k8s.io.api.core.v1.ObjectReference\x12\x0f\n\x07\x63olumns\x18\x14 \x03(\t\x12\x15\n\rfeatureFilter\x18\x15 \x01(\t\x12\x12\n\ndataFilter\x18\x16 \x01(\t\x12\x15\n\rreferenceType\x18\x17 \x01(\t\x12\x0f\n\x07periods\x18\x18 \x01(\x05\"\xac\x01\n\x12\x44\x61taTestCaseResult\x12\x0c\n\x04name\x18\x01 \x01(\t\x12T\n\x06\x61\x63tual\x18\x02 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.Measurement\x12\x0f\n\x07\x66\x61ilure\x18\x03 \x01(\x08\x12\r\n\x05\x65rror\x18\x04 \x01(\x08\x12\x12\n\nfailureMsg\x18\x05 \x01(\t\"t\n\x0cGithubEvents\x12\x19\n\x11gitConnectionName\x18\x01 \x01(\t\x12\x12\n\nrepository\x18\x02 \x01(\t\x12\x0e\n\x06\x62ranch\x18\x03 \x01(\t\x12\x15\n\rblobNameRegex\x18\x04 \x01(\t\x12\x0e\n\x06\x65vents\x18\x05 \x03(\t\"z\n\x08GpuClass\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12\x12\n\nregionName\x18\x02 \x01(\t\x12\x0c\n\x04vcpu\x18\x03 \x01(\x05\x12>\n\x06gpumem\x18\x04 \x01(\x0b\x32..k8s.io.apimachinery.pkg.api.resource.Quantity\"\xb5\x01\n\x0cGpuClassCost\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12\x0e\n\x06region\x18\x02 \x01(\t\x12\x45\n\rcostPerMinute\x18\x03 \x01(\x0b\x32..k8s.io.apimachinery.pkg.api.resource.Quantity\x12@\n\x08\x63ostSpot\x18\x04 \x01(\x0b\x32..k8s.io.apimachinery.pkg.api.resource.Quantity\"c\n\rHistogramData\x12\x0c\n\x04\x62ins\x18\x01 \x03(\x01\x12\x12\n\ncategories\x18\x02 \x03(\t\x12\x0e\n\x06\x63ounts\x18\x03 \x03(\x01\x12\x0f\n\x07missing\x18\x04 \x01(\x05\x12\x0f\n\x07invalid\x18\x05 \x01(\x05\"I\n\x06Images\x12\x14\n\x0ctrainerImage\x18\x01 \x01(\t\x12\x11\n\tdataImage\x18\x02 \x01(\t\x12\x16\n\x0epublisherImage\x18\x03 \x01(\t\"\xaf\x01\n\rLastRunStatus\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\x12?\n\x0b\x63ompletedAt\x18\x03 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x10\n\x08\x64uration\x18\x04 \x01(\x05\x12\x15\n\rfailureReason\x18\x05 \x01(\t\x12\x16\n\x0e\x66\x61ilureMessage\x18\x06 \x01(\t\"*\n\x03Lib\x12\x12\n\nframeworks\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\"u\n\x04Logs\x12\x12\n\nbucketName\x18\x01 \x01(\t\x12Y\n\ncontainers\x18\x02 \x03(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.ContainerLog\"\xa9\x01\n\x0bMLFramework\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12V\n\x04spec\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.MLFrameworkSpec\"\xa8\x01\n\x0fMLFrameworkList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12S\n\x05items\x18\x02 \x03(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.MLFramework\"R\n\x0fMLFrameworkSpec\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\t\x12\x0c\n\x04lang\x18\x04 \x01(\t\"\x8c\x01\n\x0cMachineClass\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12\x12\n\nregionName\x18\x02 \x01(\t\x12;\n\x03mem\x18\x03 \x01(\x0b\x32..k8s.io.apimachinery.pkg.api.resource.Quantity\x12\x0c\n\x04vcpu\x18\x04 \x01(\x05\x12\x0f\n\x07storage\x18\x05 \x01(\t\"\xb9\x01\n\x10MachineClassCost\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12\x0e\n\x06region\x18\x02 \x01(\t\x12\x45\n\rcostPerMinute\x18\x03 \x01(\x0b\x32..k8s.io.apimachinery.pkg.api.resource.Quantity\x12@\n\x08\x63ostSpot\x18\x04 \x01(\x0b\x32..k8s.io.apimachinery.pkg.api.resource.Quantity\"\xab\x01\n\x0cManagedImage\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12W\n\x04spec\x18\x02 \x01(\x0b\x32I.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.ManagedImageSpec\"\xaa\x01\n\x10ManagedImageList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12T\n\x05items\x18\x02 \x03(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.ManagedImage\"\xbb\x03\n\x10ManagedImageSpec\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x10\n\x08registry\x18\x02 \x01(\t\x12\x12\n\nrepository\x18\x03 \x01(\t\x12\x0b\n\x03tag\x18\x04 \x01(\t\x12\'\n\x03\x65nv\x18\x05 \x03(\x0b\x32\x1a.k8s.io.api.core.v1.EnvVar\x12\x0b\n\x03gpu\x18\x06 \x01(\x08\x12\x0e\n\x06\x61\x63tive\x18\x07 \x01(\x08\x12\x0f\n\x07preload\x18\x08 \x01(\x08\x12:\n\rconnectionRef\x18\t \x01(\x0b\x32#.k8s.io.api.core.v1.ObjectReference\x12\x0c\n\x04\x62\x61se\x18\n \x01(\t\x12\x0c\n\x04role\x18\x0b \x01(\t\x12\x13\n\x0bmantainedBy\x18\x0c \x01(\t\x12\x0b\n\x03uri\x18\r \x01(\t\x12\x12\n\nframeworks\x18\x0e \x03(\t\x12J\n\x04libs\x18\x0f \x03(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.Lib\x12\n\n\x02os\x18\x10 \x01(\t\x12\x11\n\tosVersion\x18\x11 \x01(\t\x12\x0f\n\x07private\x18\x12 \x01(\x08\"\x9a\x02\n\x0bMeasurement\x12\x33\n\x06\x65ntity\x18\x01 \x01(\x0b\x32#.k8s.io.api.core.v1.ObjectReference\x12\x0e\n\x06\x63olumn\x18\x02 \x01(\t\x12\x0e\n\x06metric\x18\x03 \x01(\t\x12\r\n\x05value\x18\x04 \x01(\x01\x12\x0e\n\x06stddev\x18\x05 \x01(\x01\x12\x0f\n\x07\x62oolQty\x18\x06 \x01(\x08\x12\x10\n\x08\x63\x61tegory\x18\x07 \x01(\t\x12\x10\n\x08valueSet\x18\x08 \x03(\t\x12=\n\ttimePoint\x18\t \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x10\n\x08taskType\x18\n \x01(\t\x12\x11\n\talgorithm\x18\x0b \x01(\t\"\xb3\x02\n\x13ModelDeploymentSpec\x12\x35\n\x08modelRef\x18\x01 \x01(\x0b\x32#.k8s.io.api.core.v1.ObjectReference\x12\x0c\n\x04port\x18\x02 \x01(\x05\x12\x14\n\x0cmodelVersion\x18\x03 \x01(\t\x12\x0f\n\x07traffic\x18\x04 \x01(\x05\x12\x0c\n\x04role\x18\x05 \x01(\t\x12\x10\n\x08mountTar\x18\t \x01(\x08\x12\x17\n\x0ftrafficSelector\x18\n \x01(\t\x12\x37\n\napprovedBy\x18\x0c \x01(\x0b\x32#.k8s.io.api.core.v1.ObjectReference\x12>\n\napprovedAt\x18\r \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\"\xea\x01\n\x10NotificationSpec\x12\x10\n\x08\x65rrorTTL\x18\x02 \x01(\x05\x12\x12\n\nsuccessTTL\x18\x04 \x01(\x05\x12\x14\n\x0cnotifierName\x18\x05 \x01(\t\x12i\n\x08selector\x18\x06 \x03(\x0b\x32W.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.NotificationSpec.SelectorEntry\x1a/\n\rSelectorEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"-\n\rObjectiveSpec\x12\x0e\n\x06metric\x18\x01 \x01(\t\x12\x0c\n\x04goal\x18\x02 \x01(\t\"^\n\x07PRCurve\x12S\n\x06values\x18\x01 \x03(\x0b\x32\x43.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.CurvePoint\"\x93\x02\n\x0eParameterRange\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x0b\n\x03low\x18\x03 \x01(\x01\x12\x0c\n\x04high\x18\x04 \x01(\x01\x12\x0c\n\x04step\x18\x05 \x01(\x05\x12\x0b\n\x03log\x18\x06 \x01(\x08\x12\x0f\n\x07\x63hoices\x18\x07 \x03(\t\x12\x14\n\x0c\x64\x65\x66\x61ultValue\x18\x08 \x01(\x01\x12\x15\n\rdefaultChoice\x18\t \x01(\t\x12\x13\n\x0b\x63onditional\x18\n \x01(\x08\x12\x0e\n\x06parent\x18\x0b \x01(\t\x12\x16\n\x0eparentValueCat\x18\x0c \x01(\t\x12\x1a\n\x12parentValueInteger\x18\r \x01(\x05\x12\x18\n\x10parentValueFloat\x18\x0e \x01(\x01\"m\n\x0fPermissionsSpec\x12Z\n\x0cstakeholders\x18\x01 \x03(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.Stakeholder\"\xb1\x01\n\x0fPretrainedModel\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12Z\n\x04spec\x18\x02 \x01(\x0b\x32L.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.PretrainedModelSpec\"\xb0\x01\n\x13PretrainedModelList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12W\n\x05items\x18\x02 \x03(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.PretrainedModel\"$\n\x13PretrainedModelSpec\x12\r\n\x05image\x18\x01 \x01(\t\"\xad\x01\n\rPublicDataset\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12X\n\x04spec\x18\x02 \x01(\x0b\x32J.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.PublicDatasetSpec\"\xac\x01\n\x11PublicDatasetList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12U\n\x05items\x18\x02 \x03(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.PublicDataset\"\xb6\x02\n\x11PublicDatasetSpec\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0c\n\x04task\x18\x03 \x01(\t\x12\x10\n\x08openMLID\x18\x04 \x01(\t\x12\x0f\n\x07\x64\x61taUrl\x18\x05 \x01(\t\x12\x10\n\x08\x63itation\x18\x06 \x01(\t\x12\x0c\n\x04rows\x18\x07 \x01(\x05\x12\x0f\n\x07\x63olumns\x18\x08 \x01(\x05\x12\x10\n\x08\x66ileSize\x18\t \x01(\x05\x12\x14\n\x0ctargetColumn\x18\n \x01(\t\x12\x10\n\x08industry\x18\x0b \x01(\t\x12\x12\n\nimbalanced\x18\x0c \x01(\x08\x12\x14\n\x0c\x64\x61tasourceCR\x18\r \x01(\t\x12\x11\n\tdatasetCR\x18\x0e \x01(\t\x12\x0f\n\x07studyCR\x18\x0f \x01(\t\x12\x15\n\rdataProductCR\x18\x10 \x01(\t\"\xb6\x01\n\x06Region\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12\x1d\n\x15\x64\x65\x66\x61ultDatacenterName\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x13\n\x0b\x62illingCode\x18\x04 \x01(\t\x12X\n\x0b\x64\x61tacenters\x18\x05 \x03(\x0b\x32\x43.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.DataCenter\"\xe2\x01\n\x0cResourceSpec\x12\x14\n\x0cworkloadName\x18\x01 \x01(\t\x12\x0e\n\x06\x63ustom\x18\x02 \x01(\x08\x12\x35\n\x08\x63puImage\x18\x03 \x01(\x0b\x32#.k8s.io.api.core.v1.ObjectReference\x12\x35\n\x08gpuImage\x18\x04 \x01(\x0b\x32#.k8s.io.api.core.v1.ObjectReference\x12>\n\x0crequirements\x18\x05 \x01(\x0b\x32(.k8s.io.api.core.v1.ResourceRequirements\"b\n\x0bRocAucCurve\x12S\n\x06values\x18\x01 \x03(\x0b\x32\x43.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.CurvePoint\"\xcd\x01\n\x0bRunSchedule\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x0c\n\x04\x63ron\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\x15\n\rmaxRetryCount\x18\x04 \x01(\x05\x12\x15\n\rretryDelaySec\x18\x05 \x01(\x05\x12\x12\n\ntimeoutSec\x18\x06 \x01(\x05\x12\x10\n\x08timezone\x18\x07 \x01(\t\x12=\n\tnextRunAt\x18\x08 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\"\xfe\x01\n\x11RunScheduleStatus\x12=\n\tlastRunAt\x18\x01 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x15\n\rfailureReason\x18\x02 \x01(\t\x12\x16\n\x0e\x66\x61ilureMessage\x18\x03 \x01(\t\x12\x13\n\x0blastRunName\x18\x04 \x01(\t\x12R\n\x0blastRunLogs\x18\x05 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.Logs\x12\x12\n\nretryCount\x18\x06 \x01(\x05\"R\n\x0bStakeholder\x12\x0f\n\x07\x61\x63\x63ount\x18\x01 \x01(\t\x12\x32\n\x05roles\x18\x02 \x03(\x0b\x32#.k8s.io.api.core.v1.ObjectReference\"r\n\tTestSuite\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12T\n\x05tests\x18\x02 \x03(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.DataTestCase\"\xc7\x02\n\x0fTestSuiteResult\x12\x36\n\tentityRef\x18\x01 \x01(\x0b\x32#.k8s.io.api.core.v1.ObjectReference\x12\x10\n\x08\x66\x61ilures\x18\x02 \x01(\x05\x12\x0e\n\x06\x65rrors\x18\x03 \x01(\x05\x12=\n\tstartedAt\x18\x04 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12?\n\x0b\x63ompletedAt\x18\x05 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12Z\n\x05tests\x18\x06 \x03(\x0b\x32K.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.DataTestCaseResult\"G\n\x0fWorkerRunResult\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\x0c\n\x04task\x18\x03 \x01(\t\x12\r\n\x05\x65rror\x18\x04 \x01(\t\"\xad\x01\n\rWorkloadClass\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12X\n\x04spec\x18\x02 \x01(\x0b\x32J.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.WorkloadClassSpec\"\xac\x01\n\x11WorkloadClassList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12U\n\x05items\x18\x02 \x03(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.WorkloadClass\"u\n\x11WorkloadClassSpec\x12`\n\x11resourcesTemplate\x18\x01 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.ResourceSpecB9Z7github.com/metaprov/modelaapi/pkg/apis/catalog/v1alpha1')



_ACCESSSPEC = DESCRIPTOR.message_types_by_name['AccessSpec']
_ALGORITHM = DESCRIPTOR.message_types_by_name['Algorithm']
_ALGORITHMLIST = DESCRIPTOR.message_types_by_name['AlgorithmList']
_ALGORITHMSPEC = DESCRIPTOR.message_types_by_name['AlgorithmSpec']
_CLOUD = DESCRIPTOR.message_types_by_name['Cloud']
_CLOUDLIST = DESCRIPTOR.message_types_by_name['CloudList']
_CLOUDSPEC = DESCRIPTOR.message_types_by_name['CloudSpec']
_CLOUDSTATUS = DESCRIPTOR.message_types_by_name['CloudStatus']
_COMPILERSPEC = DESCRIPTOR.message_types_by_name['CompilerSpec']
_CONFUSIONMATRIX = DESCRIPTOR.message_types_by_name['ConfusionMatrix']
_CONFUSIONMATRIXROW = DESCRIPTOR.message_types_by_name['ConfusionMatrixRow']
_CONTAINERLOG = DESCRIPTOR.message_types_by_name['ContainerLog']
_CURVEPOINT = DESCRIPTOR.message_types_by_name['CurvePoint']
_DATACENTER = DESCRIPTOR.message_types_by_name['DataCenter']
_DATATESTCASE = DESCRIPTOR.message_types_by_name['DataTestCase']
_DATATESTCASERESULT = DESCRIPTOR.message_types_by_name['DataTestCaseResult']
_GITHUBEVENTS = DESCRIPTOR.message_types_by_name['GithubEvents']
_GPUCLASS = DESCRIPTOR.message_types_by_name['GpuClass']
_GPUCLASSCOST = DESCRIPTOR.message_types_by_name['GpuClassCost']
_HISTOGRAMDATA = DESCRIPTOR.message_types_by_name['HistogramData']
_IMAGES = DESCRIPTOR.message_types_by_name['Images']
_LASTRUNSTATUS = DESCRIPTOR.message_types_by_name['LastRunStatus']
_LIB = DESCRIPTOR.message_types_by_name['Lib']
_LOGS = DESCRIPTOR.message_types_by_name['Logs']
_MLFRAMEWORK = DESCRIPTOR.message_types_by_name['MLFramework']
_MLFRAMEWORKLIST = DESCRIPTOR.message_types_by_name['MLFrameworkList']
_MLFRAMEWORKSPEC = DESCRIPTOR.message_types_by_name['MLFrameworkSpec']
_MACHINECLASS = DESCRIPTOR.message_types_by_name['MachineClass']
_MACHINECLASSCOST = DESCRIPTOR.message_types_by_name['MachineClassCost']
_MANAGEDIMAGE = DESCRIPTOR.message_types_by_name['ManagedImage']
_MANAGEDIMAGELIST = DESCRIPTOR.message_types_by_name['ManagedImageList']
_MANAGEDIMAGESPEC = DESCRIPTOR.message_types_by_name['ManagedImageSpec']
_MEASUREMENT = DESCRIPTOR.message_types_by_name['Measurement']
_MODELDEPLOYMENTSPEC = DESCRIPTOR.message_types_by_name['ModelDeploymentSpec']
_NOTIFICATIONSPEC = DESCRIPTOR.message_types_by_name['NotificationSpec']
_NOTIFICATIONSPEC_SELECTORENTRY = _NOTIFICATIONSPEC.nested_types_by_name['SelectorEntry']
_OBJECTIVESPEC = DESCRIPTOR.message_types_by_name['ObjectiveSpec']
_PRCURVE = DESCRIPTOR.message_types_by_name['PRCurve']
_PARAMETERRANGE = DESCRIPTOR.message_types_by_name['ParameterRange']
_PERMISSIONSSPEC = DESCRIPTOR.message_types_by_name['PermissionsSpec']
_PRETRAINEDMODEL = DESCRIPTOR.message_types_by_name['PretrainedModel']
_PRETRAINEDMODELLIST = DESCRIPTOR.message_types_by_name['PretrainedModelList']
_PRETRAINEDMODELSPEC = DESCRIPTOR.message_types_by_name['PretrainedModelSpec']
_PUBLICDATASET = DESCRIPTOR.message_types_by_name['PublicDataset']
_PUBLICDATASETLIST = DESCRIPTOR.message_types_by_name['PublicDatasetList']
_PUBLICDATASETSPEC = DESCRIPTOR.message_types_by_name['PublicDatasetSpec']
_REGION = DESCRIPTOR.message_types_by_name['Region']
_RESOURCESPEC = DESCRIPTOR.message_types_by_name['ResourceSpec']
_ROCAUCCURVE = DESCRIPTOR.message_types_by_name['RocAucCurve']
_RUNSCHEDULE = DESCRIPTOR.message_types_by_name['RunSchedule']
_RUNSCHEDULESTATUS = DESCRIPTOR.message_types_by_name['RunScheduleStatus']
_STAKEHOLDER = DESCRIPTOR.message_types_by_name['Stakeholder']
_TESTSUITE = DESCRIPTOR.message_types_by_name['TestSuite']
_TESTSUITERESULT = DESCRIPTOR.message_types_by_name['TestSuiteResult']
_WORKERRUNRESULT = DESCRIPTOR.message_types_by_name['WorkerRunResult']
_WORKLOADCLASS = DESCRIPTOR.message_types_by_name['WorkloadClass']
_WORKLOADCLASSLIST = DESCRIPTOR.message_types_by_name['WorkloadClassList']
_WORKLOADCLASSSPEC = DESCRIPTOR.message_types_by_name['WorkloadClassSpec']
AccessSpec = _reflection.GeneratedProtocolMessageType('AccessSpec', (_message.Message,), {
  'DESCRIPTOR' : _ACCESSSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.AccessSpec)
  })
_sym_db.RegisterMessage(AccessSpec)

Algorithm = _reflection.GeneratedProtocolMessageType('Algorithm', (_message.Message,), {
  'DESCRIPTOR' : _ALGORITHM,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.Algorithm)
  })
_sym_db.RegisterMessage(Algorithm)

AlgorithmList = _reflection.GeneratedProtocolMessageType('AlgorithmList', (_message.Message,), {
  'DESCRIPTOR' : _ALGORITHMLIST,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.AlgorithmList)
  })
_sym_db.RegisterMessage(AlgorithmList)

AlgorithmSpec = _reflection.GeneratedProtocolMessageType('AlgorithmSpec', (_message.Message,), {
  'DESCRIPTOR' : _ALGORITHMSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.AlgorithmSpec)
  })
_sym_db.RegisterMessage(AlgorithmSpec)

Cloud = _reflection.GeneratedProtocolMessageType('Cloud', (_message.Message,), {
  'DESCRIPTOR' : _CLOUD,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.Cloud)
  })
_sym_db.RegisterMessage(Cloud)

CloudList = _reflection.GeneratedProtocolMessageType('CloudList', (_message.Message,), {
  'DESCRIPTOR' : _CLOUDLIST,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.CloudList)
  })
_sym_db.RegisterMessage(CloudList)

CloudSpec = _reflection.GeneratedProtocolMessageType('CloudSpec', (_message.Message,), {
  'DESCRIPTOR' : _CLOUDSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.CloudSpec)
  })
_sym_db.RegisterMessage(CloudSpec)

CloudStatus = _reflection.GeneratedProtocolMessageType('CloudStatus', (_message.Message,), {
  'DESCRIPTOR' : _CLOUDSTATUS,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.CloudStatus)
  })
_sym_db.RegisterMessage(CloudStatus)

CompilerSpec = _reflection.GeneratedProtocolMessageType('CompilerSpec', (_message.Message,), {
  'DESCRIPTOR' : _COMPILERSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.CompilerSpec)
  })
_sym_db.RegisterMessage(CompilerSpec)

ConfusionMatrix = _reflection.GeneratedProtocolMessageType('ConfusionMatrix', (_message.Message,), {
  'DESCRIPTOR' : _CONFUSIONMATRIX,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.ConfusionMatrix)
  })
_sym_db.RegisterMessage(ConfusionMatrix)

ConfusionMatrixRow = _reflection.GeneratedProtocolMessageType('ConfusionMatrixRow', (_message.Message,), {
  'DESCRIPTOR' : _CONFUSIONMATRIXROW,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.ConfusionMatrixRow)
  })
_sym_db.RegisterMessage(ConfusionMatrixRow)

ContainerLog = _reflection.GeneratedProtocolMessageType('ContainerLog', (_message.Message,), {
  'DESCRIPTOR' : _CONTAINERLOG,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.ContainerLog)
  })
_sym_db.RegisterMessage(ContainerLog)

CurvePoint = _reflection.GeneratedProtocolMessageType('CurvePoint', (_message.Message,), {
  'DESCRIPTOR' : _CURVEPOINT,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.CurvePoint)
  })
_sym_db.RegisterMessage(CurvePoint)

DataCenter = _reflection.GeneratedProtocolMessageType('DataCenter', (_message.Message,), {
  'DESCRIPTOR' : _DATACENTER,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.DataCenter)
  })
_sym_db.RegisterMessage(DataCenter)

DataTestCase = _reflection.GeneratedProtocolMessageType('DataTestCase', (_message.Message,), {
  'DESCRIPTOR' : _DATATESTCASE,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.DataTestCase)
  })
_sym_db.RegisterMessage(DataTestCase)

DataTestCaseResult = _reflection.GeneratedProtocolMessageType('DataTestCaseResult', (_message.Message,), {
  'DESCRIPTOR' : _DATATESTCASERESULT,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.DataTestCaseResult)
  })
_sym_db.RegisterMessage(DataTestCaseResult)

GithubEvents = _reflection.GeneratedProtocolMessageType('GithubEvents', (_message.Message,), {
  'DESCRIPTOR' : _GITHUBEVENTS,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.GithubEvents)
  })
_sym_db.RegisterMessage(GithubEvents)

GpuClass = _reflection.GeneratedProtocolMessageType('GpuClass', (_message.Message,), {
  'DESCRIPTOR' : _GPUCLASS,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.GpuClass)
  })
_sym_db.RegisterMessage(GpuClass)

GpuClassCost = _reflection.GeneratedProtocolMessageType('GpuClassCost', (_message.Message,), {
  'DESCRIPTOR' : _GPUCLASSCOST,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.GpuClassCost)
  })
_sym_db.RegisterMessage(GpuClassCost)

HistogramData = _reflection.GeneratedProtocolMessageType('HistogramData', (_message.Message,), {
  'DESCRIPTOR' : _HISTOGRAMDATA,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.HistogramData)
  })
_sym_db.RegisterMessage(HistogramData)

Images = _reflection.GeneratedProtocolMessageType('Images', (_message.Message,), {
  'DESCRIPTOR' : _IMAGES,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.Images)
  })
_sym_db.RegisterMessage(Images)

LastRunStatus = _reflection.GeneratedProtocolMessageType('LastRunStatus', (_message.Message,), {
  'DESCRIPTOR' : _LASTRUNSTATUS,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.LastRunStatus)
  })
_sym_db.RegisterMessage(LastRunStatus)

Lib = _reflection.GeneratedProtocolMessageType('Lib', (_message.Message,), {
  'DESCRIPTOR' : _LIB,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.Lib)
  })
_sym_db.RegisterMessage(Lib)

Logs = _reflection.GeneratedProtocolMessageType('Logs', (_message.Message,), {
  'DESCRIPTOR' : _LOGS,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.Logs)
  })
_sym_db.RegisterMessage(Logs)

MLFramework = _reflection.GeneratedProtocolMessageType('MLFramework', (_message.Message,), {
  'DESCRIPTOR' : _MLFRAMEWORK,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.MLFramework)
  })
_sym_db.RegisterMessage(MLFramework)

MLFrameworkList = _reflection.GeneratedProtocolMessageType('MLFrameworkList', (_message.Message,), {
  'DESCRIPTOR' : _MLFRAMEWORKLIST,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.MLFrameworkList)
  })
_sym_db.RegisterMessage(MLFrameworkList)

MLFrameworkSpec = _reflection.GeneratedProtocolMessageType('MLFrameworkSpec', (_message.Message,), {
  'DESCRIPTOR' : _MLFRAMEWORKSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.MLFrameworkSpec)
  })
_sym_db.RegisterMessage(MLFrameworkSpec)

MachineClass = _reflection.GeneratedProtocolMessageType('MachineClass', (_message.Message,), {
  'DESCRIPTOR' : _MACHINECLASS,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.MachineClass)
  })
_sym_db.RegisterMessage(MachineClass)

MachineClassCost = _reflection.GeneratedProtocolMessageType('MachineClassCost', (_message.Message,), {
  'DESCRIPTOR' : _MACHINECLASSCOST,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.MachineClassCost)
  })
_sym_db.RegisterMessage(MachineClassCost)

ManagedImage = _reflection.GeneratedProtocolMessageType('ManagedImage', (_message.Message,), {
  'DESCRIPTOR' : _MANAGEDIMAGE,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.ManagedImage)
  })
_sym_db.RegisterMessage(ManagedImage)

ManagedImageList = _reflection.GeneratedProtocolMessageType('ManagedImageList', (_message.Message,), {
  'DESCRIPTOR' : _MANAGEDIMAGELIST,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.ManagedImageList)
  })
_sym_db.RegisterMessage(ManagedImageList)

ManagedImageSpec = _reflection.GeneratedProtocolMessageType('ManagedImageSpec', (_message.Message,), {
  'DESCRIPTOR' : _MANAGEDIMAGESPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.ManagedImageSpec)
  })
_sym_db.RegisterMessage(ManagedImageSpec)

Measurement = _reflection.GeneratedProtocolMessageType('Measurement', (_message.Message,), {
  'DESCRIPTOR' : _MEASUREMENT,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.Measurement)
  })
_sym_db.RegisterMessage(Measurement)

ModelDeploymentSpec = _reflection.GeneratedProtocolMessageType('ModelDeploymentSpec', (_message.Message,), {
  'DESCRIPTOR' : _MODELDEPLOYMENTSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.ModelDeploymentSpec)
  })
_sym_db.RegisterMessage(ModelDeploymentSpec)

NotificationSpec = _reflection.GeneratedProtocolMessageType('NotificationSpec', (_message.Message,), {

  'SelectorEntry' : _reflection.GeneratedProtocolMessageType('SelectorEntry', (_message.Message,), {
    'DESCRIPTOR' : _NOTIFICATIONSPEC_SELECTORENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.generated_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.NotificationSpec.SelectorEntry)
    })
  ,
  'DESCRIPTOR' : _NOTIFICATIONSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.NotificationSpec)
  })
_sym_db.RegisterMessage(NotificationSpec)
_sym_db.RegisterMessage(NotificationSpec.SelectorEntry)

ObjectiveSpec = _reflection.GeneratedProtocolMessageType('ObjectiveSpec', (_message.Message,), {
  'DESCRIPTOR' : _OBJECTIVESPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.ObjectiveSpec)
  })
_sym_db.RegisterMessage(ObjectiveSpec)

PRCurve = _reflection.GeneratedProtocolMessageType('PRCurve', (_message.Message,), {
  'DESCRIPTOR' : _PRCURVE,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.PRCurve)
  })
_sym_db.RegisterMessage(PRCurve)

ParameterRange = _reflection.GeneratedProtocolMessageType('ParameterRange', (_message.Message,), {
  'DESCRIPTOR' : _PARAMETERRANGE,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.ParameterRange)
  })
_sym_db.RegisterMessage(ParameterRange)

PermissionsSpec = _reflection.GeneratedProtocolMessageType('PermissionsSpec', (_message.Message,), {
  'DESCRIPTOR' : _PERMISSIONSSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.PermissionsSpec)
  })
_sym_db.RegisterMessage(PermissionsSpec)

PretrainedModel = _reflection.GeneratedProtocolMessageType('PretrainedModel', (_message.Message,), {
  'DESCRIPTOR' : _PRETRAINEDMODEL,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.PretrainedModel)
  })
_sym_db.RegisterMessage(PretrainedModel)

PretrainedModelList = _reflection.GeneratedProtocolMessageType('PretrainedModelList', (_message.Message,), {
  'DESCRIPTOR' : _PRETRAINEDMODELLIST,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.PretrainedModelList)
  })
_sym_db.RegisterMessage(PretrainedModelList)

PretrainedModelSpec = _reflection.GeneratedProtocolMessageType('PretrainedModelSpec', (_message.Message,), {
  'DESCRIPTOR' : _PRETRAINEDMODELSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.PretrainedModelSpec)
  })
_sym_db.RegisterMessage(PretrainedModelSpec)

PublicDataset = _reflection.GeneratedProtocolMessageType('PublicDataset', (_message.Message,), {
  'DESCRIPTOR' : _PUBLICDATASET,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.PublicDataset)
  })
_sym_db.RegisterMessage(PublicDataset)

PublicDatasetList = _reflection.GeneratedProtocolMessageType('PublicDatasetList', (_message.Message,), {
  'DESCRIPTOR' : _PUBLICDATASETLIST,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.PublicDatasetList)
  })
_sym_db.RegisterMessage(PublicDatasetList)

PublicDatasetSpec = _reflection.GeneratedProtocolMessageType('PublicDatasetSpec', (_message.Message,), {
  'DESCRIPTOR' : _PUBLICDATASETSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.PublicDatasetSpec)
  })
_sym_db.RegisterMessage(PublicDatasetSpec)

Region = _reflection.GeneratedProtocolMessageType('Region', (_message.Message,), {
  'DESCRIPTOR' : _REGION,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.Region)
  })
_sym_db.RegisterMessage(Region)

ResourceSpec = _reflection.GeneratedProtocolMessageType('ResourceSpec', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCESPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.ResourceSpec)
  })
_sym_db.RegisterMessage(ResourceSpec)

RocAucCurve = _reflection.GeneratedProtocolMessageType('RocAucCurve', (_message.Message,), {
  'DESCRIPTOR' : _ROCAUCCURVE,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.RocAucCurve)
  })
_sym_db.RegisterMessage(RocAucCurve)

RunSchedule = _reflection.GeneratedProtocolMessageType('RunSchedule', (_message.Message,), {
  'DESCRIPTOR' : _RUNSCHEDULE,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.RunSchedule)
  })
_sym_db.RegisterMessage(RunSchedule)

RunScheduleStatus = _reflection.GeneratedProtocolMessageType('RunScheduleStatus', (_message.Message,), {
  'DESCRIPTOR' : _RUNSCHEDULESTATUS,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.RunScheduleStatus)
  })
_sym_db.RegisterMessage(RunScheduleStatus)

Stakeholder = _reflection.GeneratedProtocolMessageType('Stakeholder', (_message.Message,), {
  'DESCRIPTOR' : _STAKEHOLDER,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.Stakeholder)
  })
_sym_db.RegisterMessage(Stakeholder)

TestSuite = _reflection.GeneratedProtocolMessageType('TestSuite', (_message.Message,), {
  'DESCRIPTOR' : _TESTSUITE,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.TestSuite)
  })
_sym_db.RegisterMessage(TestSuite)

TestSuiteResult = _reflection.GeneratedProtocolMessageType('TestSuiteResult', (_message.Message,), {
  'DESCRIPTOR' : _TESTSUITERESULT,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.TestSuiteResult)
  })
_sym_db.RegisterMessage(TestSuiteResult)

WorkerRunResult = _reflection.GeneratedProtocolMessageType('WorkerRunResult', (_message.Message,), {
  'DESCRIPTOR' : _WORKERRUNRESULT,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.WorkerRunResult)
  })
_sym_db.RegisterMessage(WorkerRunResult)

WorkloadClass = _reflection.GeneratedProtocolMessageType('WorkloadClass', (_message.Message,), {
  'DESCRIPTOR' : _WORKLOADCLASS,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.WorkloadClass)
  })
_sym_db.RegisterMessage(WorkloadClass)

WorkloadClassList = _reflection.GeneratedProtocolMessageType('WorkloadClassList', (_message.Message,), {
  'DESCRIPTOR' : _WORKLOADCLASSLIST,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.WorkloadClassList)
  })
_sym_db.RegisterMessage(WorkloadClassList)

WorkloadClassSpec = _reflection.GeneratedProtocolMessageType('WorkloadClassSpec', (_message.Message,), {
  'DESCRIPTOR' : _WORKLOADCLASSSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.WorkloadClassSpec)
  })
_sym_db.RegisterMessage(WorkloadClassSpec)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z7github.com/metaprov/modelaapi/pkg/apis/catalog/v1alpha1'
  _NOTIFICATIONSPEC_SELECTORENTRY._options = None
  _NOTIFICATIONSPEC_SELECTORENTRY._serialized_options = b'8\001'
  _ACCESSSPEC._serialized_start=382
  _ACCESSSPEC._serialized_end=556
  _ALGORITHM._serialized_start=559
  _ALGORITHM._serialized_end=724
  _ALGORITHMLIST._serialized_start=727
  _ALGORITHMLIST._serialized_end=891
  _ALGORITHMSPEC._serialized_start=894
  _ALGORITHMSPEC._serialized_end=1086
  _CLOUD._serialized_start=1089
  _CLOUD._serialized_end=1332
  _CLOUDLIST._serialized_start=1335
  _CLOUDLIST._serialized_end=1491
  _CLOUDSPEC._serialized_start=1494
  _CLOUDSPEC._serialized_end=1858
  _CLOUDSTATUS._serialized_start=1861
  _CLOUDSTATUS._serialized_end=2060
  _COMPILERSPEC._serialized_start=2062
  _COMPILERSPEC._serialized_end=2127
  _CONFUSIONMATRIX._serialized_start=2129
  _CONFUSIONMATRIX._serialized_end=2237
  _CONFUSIONMATRIXROW._serialized_start=2239
  _CONFUSIONMATRIXROW._serialized_end=2309
  _CONTAINERLOG._serialized_start=2311
  _CONTAINERLOG._serialized_end=2370
  _CURVEPOINT._serialized_start=2372
  _CURVEPOINT._serialized_end=2406
  _DATACENTER._serialized_start=2408
  _DATACENTER._serialized_end=2448
  _DATATESTCASE._serialized_start=2451
  _DATATESTCASE._serialized_end=3032
  _DATATESTCASERESULT._serialized_start=3035
  _DATATESTCASERESULT._serialized_end=3207
  _GITHUBEVENTS._serialized_start=3209
  _GITHUBEVENTS._serialized_end=3325
  _GPUCLASS._serialized_start=3327
  _GPUCLASS._serialized_end=3449
  _GPUCLASSCOST._serialized_start=3452
  _GPUCLASSCOST._serialized_end=3633
  _HISTOGRAMDATA._serialized_start=3635
  _HISTOGRAMDATA._serialized_end=3734
  _IMAGES._serialized_start=3736
  _IMAGES._serialized_end=3809
  _LASTRUNSTATUS._serialized_start=3812
  _LASTRUNSTATUS._serialized_end=3987
  _LIB._serialized_start=3989
  _LIB._serialized_end=4031
  _LOGS._serialized_start=4033
  _LOGS._serialized_end=4150
  _MLFRAMEWORK._serialized_start=4153
  _MLFRAMEWORK._serialized_end=4322
  _MLFRAMEWORKLIST._serialized_start=4325
  _MLFRAMEWORKLIST._serialized_end=4493
  _MLFRAMEWORKSPEC._serialized_start=4495
  _MLFRAMEWORKSPEC._serialized_end=4577
  _MACHINECLASS._serialized_start=4580
  _MACHINECLASS._serialized_end=4720
  _MACHINECLASSCOST._serialized_start=4723
  _MACHINECLASSCOST._serialized_end=4908
  _MANAGEDIMAGE._serialized_start=4911
  _MANAGEDIMAGE._serialized_end=5082
  _MANAGEDIMAGELIST._serialized_start=5085
  _MANAGEDIMAGELIST._serialized_end=5255
  _MANAGEDIMAGESPEC._serialized_start=5258
  _MANAGEDIMAGESPEC._serialized_end=5701
  _MEASUREMENT._serialized_start=5704
  _MEASUREMENT._serialized_end=5986
  _MODELDEPLOYMENTSPEC._serialized_start=5989
  _MODELDEPLOYMENTSPEC._serialized_end=6296
  _NOTIFICATIONSPEC._serialized_start=6299
  _NOTIFICATIONSPEC._serialized_end=6533
  _NOTIFICATIONSPEC_SELECTORENTRY._serialized_start=6486
  _NOTIFICATIONSPEC_SELECTORENTRY._serialized_end=6533
  _OBJECTIVESPEC._serialized_start=6535
  _OBJECTIVESPEC._serialized_end=6580
  _PRCURVE._serialized_start=6582
  _PRCURVE._serialized_end=6676
  _PARAMETERRANGE._serialized_start=6679
  _PARAMETERRANGE._serialized_end=6954
  _PERMISSIONSSPEC._serialized_start=6956
  _PERMISSIONSSPEC._serialized_end=7065
  _PRETRAINEDMODEL._serialized_start=7068
  _PRETRAINEDMODEL._serialized_end=7245
  _PRETRAINEDMODELLIST._serialized_start=7248
  _PRETRAINEDMODELLIST._serialized_end=7424
  _PRETRAINEDMODELSPEC._serialized_start=7426
  _PRETRAINEDMODELSPEC._serialized_end=7462
  _PUBLICDATASET._serialized_start=7465
  _PUBLICDATASET._serialized_end=7638
  _PUBLICDATASETLIST._serialized_start=7641
  _PUBLICDATASETLIST._serialized_end=7813
  _PUBLICDATASETSPEC._serialized_start=7816
  _PUBLICDATASETSPEC._serialized_end=8126
  _REGION._serialized_start=8129
  _REGION._serialized_end=8311
  _RESOURCESPEC._serialized_start=8314
  _RESOURCESPEC._serialized_end=8540
  _ROCAUCCURVE._serialized_start=8542
  _ROCAUCCURVE._serialized_end=8640
  _RUNSCHEDULE._serialized_start=8643
  _RUNSCHEDULE._serialized_end=8848
  _RUNSCHEDULESTATUS._serialized_start=8851
  _RUNSCHEDULESTATUS._serialized_end=9105
  _STAKEHOLDER._serialized_start=9107
  _STAKEHOLDER._serialized_end=9189
  _TESTSUITE._serialized_start=9191
  _TESTSUITE._serialized_end=9305
  _TESTSUITERESULT._serialized_start=9308
  _TESTSUITERESULT._serialized_end=9635
  _WORKERRUNRESULT._serialized_start=9637
  _WORKERRUNRESULT._serialized_end=9708
  _WORKLOADCLASS._serialized_start=9711
  _WORKLOADCLASS._serialized_end=9884
  _WORKLOADCLASSLIST._serialized_start=9887
  _WORKLOADCLASSLIST._serialized_end=10059
  _WORKLOADCLASSSPEC._serialized_start=10061
  _WORKLOADCLASSSPEC._serialized_end=10178
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/virtualbucket/v1/virtualbucket.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nKgithub.com/metaprov/modelaapi/services/virtualbucket/v1/virtualbucket.proto\x12\x37github.com.metaprov.modelaapi.services.virtualbucket.v1\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x45github.com/metaprov/modelaapi/pkg/apis/infra/v1alpha1/generated.proto\"\xcd\x01\n\x19ListVirtualBucketsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12n\n\x06labels\x18\x02 \x03(\x0b\x32^.github.com.metaprov.modelaapi.services.virtualbucket.v1.ListVirtualBucketsRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x97\x01\n\x1aListVirtualBucketsResponse\x12`\n\x0evirtualbuckets\x18\x01 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucketList\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"y\n\x1a\x43reateVirtualBucketRequest\x12[\n\rvirtualbucket\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\"\x1d\n\x1b\x43reateVirtualBucketResponse\"\xa9\x01\n\x1aUpdateVirtualBucketRequest\x12[\n\rvirtualbucket\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"\x1d\n\x1bUpdateVirtualBucketResponse\":\n\x17GetVirtualBucketRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x85\x01\n\x18GetVirtualBucketResponse\x12[\n\rvirtualbucket\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"=\n\x1a\x44\x65leteVirtualBucketRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1d\n\x1b\x44\x65leteVirtualBucketResponse2\xde\t\n\x14VirtualBucketService\x12\xe5\x01\n\x12ListVirtualBuckets\x12R.github.com.metaprov.modelaapi.services.virtualbucket.v1.ListVirtualBucketsRequest\x1aS.github.com.metaprov.modelaapi.services.virtualbucket.v1.ListVirtualBucketsResponse\"&\x82\xd3\xe4\x93\x02 \x12\x1e/v1/virtualbuckets/{namespace}\x12\xdf\x01\n\x13\x43reateVirtualBucket\x12S.github.com.metaprov.modelaapi.services.virtualbucket.v1.CreateVirtualBucketRequest\x1aT.github.com.metaprov.modelaapi.services.virtualbucket.v1.CreateVirtualBucketResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\"\x12/v1/virtualbuckets:\x01*\x12\xe6\x01\n\x10GetVirtualBucket\x12P.github.com.metaprov.modelaapi.services.virtualbucket.v1.GetVirtualBucketRequest\x1aQ.github.com.metaprov.modelaapi.services.virtualbucket.v1.GetVirtualBucketResponse\"-\x82\xd3\xe4\x93\x02\'\x12%/v1/virtualbuckets/{namespace}/{name}\x12\xa0\x02\n\x13UpdateVirtualBucket\x12S.github.com.metaprov.modelaapi.services.virtualbucket.v1.UpdateVirtualBucketRequest\x1aT.github.com.metaprov.modelaapi.services.virtualbucket.v1.UpdateVirtualBucketResponse\"^\x82\xd3\xe4\x93\x02X\x1aS/v1/virtualbuckets/{virtualbucket.metadata.namespace}/{virtualbucket.metadata.name}:\x01*\x12\xef\x01\n\x13\x44\x65leteVirtualBucket\x12S.github.com.metaprov.modelaapi.services.virtualbucket.v1.DeleteVirtualBucketRequest\x1aT.github.com.metaprov.modelaapi.services.virtualbucket.v1.DeleteVirtualBucketResponse\"-\x82\xd3\xe4\x93\x02\'*%/v1/virtualbuckets/{namespace}/{name}B9Z7github.com/metaprov/modelaapi/services/virtualbucket/v1b\x06proto3')



_LISTVIRTUALBUCKETSREQUEST = DESCRIPTOR.message_types_by_name['ListVirtualBucketsRequest']
_LISTVIRTUALBUCKETSREQUEST_LABELSENTRY = _LISTVIRTUALBUCKETSREQUEST.nested_types_by_name['LabelsEntry']
_LISTVIRTUALBUCKETSRESPONSE = DESCRIPTOR.message_types_by_name['ListVirtualBucketsResponse']
_CREATEVIRTUALBUCKETREQUEST = DESCRIPTOR.message_types_by_name['CreateVirtualBucketRequest']
_CREATEVIRTUALBUCKETRESPONSE = DESCRIPTOR.message_types_by_name['CreateVirtualBucketResponse']
_UPDATEVIRTUALBUCKETREQUEST = DESCRIPTOR.message_types_by_name['UpdateVirtualBucketRequest']
_UPDATEVIRTUALBUCKETRESPONSE = DESCRIPTOR.message_types_by_name['UpdateVirtualBucketResponse']
_GETVIRTUALBUCKETREQUEST = DESCRIPTOR.message_types_by_name['GetVirtualBucketRequest']
_GETVIRTUALBUCKETRESPONSE = DESCRIPTOR.message_types_by_name['GetVirtualBucketResponse']
_DELETEVIRTUALBUCKETREQUEST = DESCRIPTOR.message_types_by_name['DeleteVirtualBucketRequest']
_DELETEVIRTUALBUCKETRESPONSE = DESCRIPTOR.message_types_by_name['DeleteVirtualBucketResponse']
ListVirtualBucketsRequest = _reflection.GeneratedProtocolMessageType('ListVirtualBucketsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTVIRTUALBUCKETSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.virtualbucket.v1.virtualbucket_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.virtualbucket.v1.ListVirtualBucketsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTVIRTUALBUCKETSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.virtualbucket.v1.virtualbucket_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.virtualbucket.v1.ListVirtualBucketsRequest)
  })
_sym_db.RegisterMessage(ListVirtualBucketsRequest)
_sym_db.RegisterMessage(ListVirtualBucketsRequest.LabelsEntry)

ListVirtualBucketsResponse = _reflection.GeneratedProtocolMessageType('ListVirtualBucketsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTVIRTUALBUCKETSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.virtualbucket.v1.virtualbucket_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.virtualbucket.v1.ListVirtualBucketsResponse)
  })
_sym_db.RegisterMessage(ListVirtualBucketsResponse)

CreateVirtualBucketRequest = _reflection.GeneratedProtocolMessageType('CreateVirtualBucketRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEVIRTUALBUCKETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.virtualbucket.v1.virtualbucket_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.virtualbucket.v1.CreateVirtualBucketRequest)
  })
_sym_db.RegisterMessage(CreateVirtualBucketRequest)

CreateVirtualBucketResponse = _reflection.GeneratedProtocolMessageType('CreateVirtualBucketResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEVIRTUALBUCKETRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.virtualbucket.v1.virtualbucket_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.virtualbucket.v1.CreateVirtualBucketResponse)
  })
_sym_db.RegisterMessage(CreateVirtualBucketResponse)

UpdateVirtualBucketRequest = _reflection.GeneratedProtocolMessageType('UpdateVirtualBucketRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEVIRTUALBUCKETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.virtualbucket.v1.virtualbucket_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.virtualbucket.v1.UpdateVirtualBucketRequest)
  })
_sym_db.RegisterMessage(UpdateVirtualBucketRequest)

UpdateVirtualBucketResponse = _reflection.GeneratedProtocolMessageType('UpdateVirtualBucketResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEVIRTUALBUCKETRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.virtualbucket.v1.virtualbucket_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.virtualbucket.v1.UpdateVirtualBucketResponse)
  })
_sym_db.RegisterMessage(UpdateVirtualBucketResponse)

GetVirtualBucketRequest = _reflection.GeneratedProtocolMessageType('GetVirtualBucketRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETVIRTUALBUCKETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.virtualbucket.v1.virtualbucket_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.virtualbucket.v1.GetVirtualBucketRequest)
  })
_sym_db.RegisterMessage(GetVirtualBucketRequest)

GetVirtualBucketResponse = _reflection.GeneratedProtocolMessageType('GetVirtualBucketResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETVIRTUALBUCKETRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.virtualbucket.v1.virtualbucket_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.virtualbucket.v1.GetVirtualBucketResponse)
  })
_sym_db.RegisterMessage(GetVirtualBucketResponse)

DeleteVirtualBucketRequest = _reflection.GeneratedProtocolMessageType('DeleteVirtualBucketRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEVIRTUALBUCKETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.virtualbucket.v1.virtualbucket_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.virtualbucket.v1.DeleteVirtualBucketRequest)
  })
_sym_db.RegisterMessage(DeleteVirtualBucketRequest)

DeleteVirtualBucketResponse = _reflection.GeneratedProtocolMessageType('DeleteVirtualBucketResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEVIRTUALBUCKETRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.virtualbucket.v1.virtualbucket_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.virtualbucket.v1.DeleteVirtualBucketResponse)
  })
_sym_db.RegisterMessage(DeleteVirtualBucketResponse)

_VIRTUALBUCKETSERVICE = DESCRIPTOR.services_by_name['VirtualBucketService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z7github.com/metaprov/modelaapi/services/virtualbucket/v1'
  _LISTVIRTUALBUCKETSREQUEST_LABELSENTRY._options = None
  _LISTVIRTUALBUCKETSREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _VIRTUALBUCKETSERVICE.methods_by_name['ListVirtualBuckets']._options = None
  _VIRTUALBUCKETSERVICE.methods_by_name['ListVirtualBuckets']._serialized_options = b'\202\323\344\223\002 \022\036/v1/virtualbuckets/{namespace}'
  _VIRTUALBUCKETSERVICE.methods_by_name['CreateVirtualBucket']._options = None
  _VIRTUALBUCKETSERVICE.methods_by_name['CreateVirtualBucket']._serialized_options = b'\202\323\344\223\002\027\"\022/v1/virtualbuckets:\001*'
  _VIRTUALBUCKETSERVICE.methods_by_name['GetVirtualBucket']._options = None
  _VIRTUALBUCKETSERVICE.methods_by_name['GetVirtualBucket']._serialized_options = b'\202\323\344\223\002\'\022%/v1/virtualbuckets/{namespace}/{name}'
  _VIRTUALBUCKETSERVICE.methods_by_name['UpdateVirtualBucket']._options = None
  _VIRTUALBUCKETSERVICE.methods_by_name['UpdateVirtualBucket']._serialized_options = b'\202\323\344\223\002X\032S/v1/virtualbuckets/{virtualbucket.metadata.namespace}/{virtualbucket.metadata.name}:\001*'
  _VIRTUALBUCKETSERVICE.methods_by_name['DeleteVirtualBucket']._options = None
  _VIRTUALBUCKETSERVICE.methods_by_name['DeleteVirtualBucket']._serialized_options = b'\202\323\344\223\002\'*%/v1/virtualbuckets/{namespace}/{name}'
  _LISTVIRTUALBUCKETSREQUEST._serialized_start=272
  _LISTVIRTUALBUCKETSREQUEST._serialized_end=477
  _LISTVIRTUALBUCKETSREQUEST_LABELSENTRY._serialized_start=432
  _LISTVIRTUALBUCKETSREQUEST_LABELSENTRY._serialized_end=477
  _LISTVIRTUALBUCKETSRESPONSE._serialized_start=480
  _LISTVIRTUALBUCKETSRESPONSE._serialized_end=631
  _CREATEVIRTUALBUCKETREQUEST._serialized_start=633
  _CREATEVIRTUALBUCKETREQUEST._serialized_end=754
  _CREATEVIRTUALBUCKETRESPONSE._serialized_start=756
  _CREATEVIRTUALBUCKETRESPONSE._serialized_end=785
  _UPDATEVIRTUALBUCKETREQUEST._serialized_start=788
  _UPDATEVIRTUALBUCKETREQUEST._serialized_end=957
  _UPDATEVIRTUALBUCKETRESPONSE._serialized_start=959
  _UPDATEVIRTUALBUCKETRESPONSE._serialized_end=988
  _GETVIRTUALBUCKETREQUEST._serialized_start=990
  _GETVIRTUALBUCKETREQUEST._serialized_end=1048
  _GETVIRTUALBUCKETRESPONSE._serialized_start=1051
  _GETVIRTUALBUCKETRESPONSE._serialized_end=1184
  _DELETEVIRTUALBUCKETREQUEST._serialized_start=1186
  _DELETEVIRTUALBUCKETREQUEST._serialized_end=1247
  _DELETEVIRTUALBUCKETRESPONSE._serialized_start=1249
  _DELETEVIRTUALBUCKETRESPONSE._serialized_end=1278
  _VIRTUALBUCKETSERVICE._serialized_start=1281
  _VIRTUALBUCKETSERVICE._serialized_end=2527
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from github.com.metaprov.modelaapi.services.modelclassrun.v1 import modelclassrun_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2


class ModelClassRunServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListModelClassRuns = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.modelclassrun.v1.ModelClassRunService/ListModelClassRuns',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.ListModelClassRunsRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.ListModelClassRunsResponse.FromString,
                )
        self.CreateModelClassRun = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.modelclassrun.v1.ModelClassRunService/CreateModelClassRun',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.CreateModelClassRunRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.CreateModelClassRunResponse.FromString,
                )
        self.GetModelClassRun = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.modelclassrun.v1.ModelClassRunService/GetModelClassRun',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.GetModelClassRunRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.GetModelClassRunResponse.FromString,
                )
        self.UpdateModelClassRun = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.modelclassrun.v1.ModelClassRunService/UpdateModelClassRun',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.UpdateModelClassRunRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.UpdateModelClassRunResponse.FromString,
                )
        self.DeleteModelClassRun = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.modelclassrun.v1.ModelClassRunService/DeleteModelClassRun',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.DeleteModelClassRunRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.DeleteModelClassRunResponse.FromString,
                )
        self.ApproveModelClassRun = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.modelclassrun.v1.ModelClassRunService/ApproveModelClassRun',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.ApproveModelClassRunRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.ApproveModelClassRunResponse.FromString,
                )
        self.DenyModelClassRun = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.modelclassrun.v1.ModelClassRunService/DenyModelClassRun',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.DenyModelClassRunRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.DenyModelClassRunResponse.FromString,
                )
        self.AbortModelClassRun = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.modelclassrun.v1.ModelClassRunService/AbortModelClassRun',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.AbortModelClassRunRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.AbortModelClassRunResponse.FromString,
                )
        self.PauseModelClassRun = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.modelclassrun.v1.ModelClassRunService/PauseModelClassRun',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.PauseModelClassRunRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.PauseModelClassRunResponse.FromString,
                )
        self.ResumeModelClassRun = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.modelclassrun.v1.ModelClassRunService/ResumeModelClassRun',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.ResumeModelClassRunRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.ResumeModelClassRunResponse.FromString,
                )


class ModelClassRunServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListModelClassRuns(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateModelClassRun(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetModelClassRun(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateModelClassRun(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteModelClassRun(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ApproveModelClassRun(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DenyModelClassRun(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AbortModelClassRun(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PauseModelClassRun(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ResumeModelClassRun(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ModelClassRunServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListModelClassRuns': grpc.unary_unary_rpc_method_handler(
                    servicer.ListModelClassRuns,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.ListModelClassRunsRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.ListModelClassRunsResponse.SerializeToString,
            ),
            'CreateModelClassRun': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateModelClassRun,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.CreateModelClassRunRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.CreateModelClassRunResponse.SerializeToString,
            ),
            'GetModelClassRun': grpc.unary_unary_rpc_method_handler(
                    servicer.GetModelClassRun,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.GetModelClassRunRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.GetModelClassRunResponse.SerializeToString,
            ),
            'UpdateModelClassRun': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateModelClassRun,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.UpdateModelClassRunRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.UpdateModelClassRunResponse.SerializeToString,
            ),
            'DeleteModelClassRun': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteModelClassRun,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.DeleteModelClassRunRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.DeleteModelClassRunResponse.SerializeToString,
            ),
            'ApproveModelClassRun': grpc.unary_unary_rpc_method_handler(
                    servicer.ApproveModelClassRun,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.ApproveModelClassRunRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.ApproveModelClassRunResponse.SerializeToString,
            ),
            'DenyModelClassRun': grpc.unary_unary_rpc_method_handler(
                    servicer.DenyModelClassRun,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.DenyModelClassRunRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.DenyModelClassRunResponse.SerializeToString,
            ),
            'AbortModelClassRun': grpc.unary_unary_rpc_method_handler(
                    servicer.AbortModelClassRun,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.AbortModelClassRunRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.AbortModelClassRunResponse.SerializeToString,
            ),
            'PauseModelClassRun': grpc.unary_unary_rpc_method_handler(
                    servicer.PauseModelClassRun,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.PauseModelClassRunRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.PauseModelClassRunResponse.SerializeToString,
            ),
            'ResumeModelClassRun': grpc.unary_unary_rpc_method_handler(
                    servicer.ResumeModelClassRun,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.ResumeModelClassRunRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.ResumeModelClassRunResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'github.com.metaprov.modelaapi.services.modelclassrun.v1.ModelClassRunService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ModelClassRunService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListModelClassRuns(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.modelclassrun.v1.ModelClassRunService/ListModelClassRuns',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.ListModelClassRunsRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.ListModelClassRunsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateModelClassRun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.modelclassrun.v1.ModelClassRunService/CreateModelClassRun',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.CreateModelClassRunRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.CreateModelClassRunResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetModelClassRun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.modelclassrun.v1.ModelClassRunService/GetModelClassRun',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.GetModelClassRunRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.GetModelClassRunResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateModelClassRun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.modelclassrun.v1.ModelClassRunService/UpdateModelClassRun',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.UpdateModelClassRunRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.UpdateModelClassRunResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteModelClassRun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.modelclassrun.v1.ModelClassRunService/DeleteModelClassRun',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.DeleteModelClassRunRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.DeleteModelClassRunResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ApproveModelClassRun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.modelclassrun.v1.ModelClassRunService/ApproveModelClassRun',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.ApproveModelClassRunRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.ApproveModelClassRunResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DenyModelClassRun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.modelclassrun.v1.ModelClassRunService/DenyModelClassRun',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.DenyModelClassRunRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.DenyModelClassRunResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AbortModelClassRun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.modelclassrun.v1.ModelClassRunService/AbortModelClassRun',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.AbortModelClassRunRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.AbortModelClassRunResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PauseModelClassRun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.modelclassrun.v1.ModelClassRunService/PauseModelClassRun',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.PauseModelClassRunRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.PauseModelClassRunResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ResumeModelClassRun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.modelclassrun.v1.ModelClassRunService/ResumeModelClassRun',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.ResumeModelClassRunRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.ResumeModelClassRunResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
